------------------------------------------------------------------------------
-- MakeMeGetMyMain - Alarms you when something happens to your character
------------------------------------------------------------------------------
-- Options.lua - Options
--
-- Author: Expelliarm5s / October 2020 / All Rights Reserved
--
-- Version 1.1.7
------------------------------------------------------------------------------
-- luacheck: ignore 212 globals DLAPI
-- luacheck: globals AceGUIWidgetLSMlists, max line length 160, ignore 212

local addonName, addon = ...
local modle = addon:NewModule("Options", "AceConsole-3.0")
local L = LibStub("AceLocale-3.0"):GetLocale(addonName)
local LSM = LibStub("LibSharedMedia-3.0")
local WidgetLists = AceGUIWidgetLSMlists
--------------------------------------------------------------------------------------------------------

--  Options
modle.defaults = {
	profile = {
	},
	global = {
		closeOnEscape = false,
		windowTransparent = false,
		windowFullMode = false,
		Fight = false,
		SoundFight = "Simon Small Blue",
		Kill = true,
		SoundKill = "Simon Small Blue",
		Whisper = true,
		SoundWhisper = "Simon Small Blue",
		Move = false,
		SoundMove = "Simon Small Blue",
		Loot = true,
		SoundLoot = "Simon Small Blue",
		LootItemIDs = "163573, 163574, 163575, 163576, 163131",
		Say = true,
		SoundSay = "Simon Small Blue",
		SayWordList = "Multiboxer, Howdy",
		BagSpace = true,
		SoundBagSpace = "Simon Small Blue",
		BagSpaceSlots = "2",
	},
}

------------------------------------------------------------------------------
-- Debug Stuff

function modle:DebugPrintf(...)
	if addon.isDebug then
		local status, res = pcall(format, ...)
		if status then
			addon:DebugLog("OPT~" .. res)
		end
	end
end

function modle:Login()
	modle:DebugPrintf("Options:Login()")

	-- see https://wow.tools/files/#search=&page=1&sort=0&desc=asc
	if LSM then
		if not addon.isClassic then
			LSM:Register("sound", "Default", 567482)
			LSM:Register("sound", "Small Chain", 567577)
			LSM:Register("sound", "Bell Toll Alliance", 566564)
			LSM:Register("sound", "Bell Toll Horde", 565853)
			LSM:Register("sound", "Auction Window Close", 567499)
			LSM:Register("sound", "Quest Failed", 567459)
			LSM:Register("sound", "Fel Nova", 568582)
			LSM:Register("sound", "Simon Large Blue", 566076)
			LSM:Register("sound", "Simon Small Blue", 567002)
			LSM:Register("sound", "Portcullis Close", 566240)
			LSM:Register("sound", "PvP Flag Taken", 569200)
			LSM:Register("sound", "Cannon", 566101)
			LSM:Register("sound", "Alarm 2", 567399)
		else
			LSM:Register("sound", "Default", SOUNDKIT.AUCTION_WINDOW_OPEN)
			LSM:Register("sound", "Small Chain", SOUNDKIT.PUT_DOWN_SMALL_CHAIN)
			LSM:Register("sound", "AH Bell", SOUNDKIT.AUCTION_WINDOW_CLOSE)
			LSM:Register("sound", "Simon Small Blue", SOUNDKIT.RAID_WARNING)
		end
	end
end

function modle.PlaySound(key)
	if LSM and key and LSM:Fetch("sound", key) then
		local sound = LSM:Fetch("sound", key)
		if sound == "Interface\\Quiet.ogg" then
			-- nix
			modle:DebugPrintf("Playing/1: silence")
		else
			-- modle:Printf("Sound %s=%s", key, LSM:Fetch("sound", key))
			-- 8.2: no more sound file paths, check against external LSM registered sounds
			if type(sound) == "string" then
				if sound:match("^Sound") then
					modle:DebugPrintf("PlaySound/2: std sound")
					PlaySound(SOUNDKIT.AUCTION_WINDOW_OPEN, "master")
				else
					modle:DebugPrintf("PlaySoundFile/2: %s", sound)
					PlaySoundFile(sound, "master")
				end
			else
				if type(sound) == "number" then
					if addon.isClassic then
						modle:DebugPrintf("PlaySound/4: %s", tostring(sound))
						PlaySound(sound, "master")
					else
						modle:DebugPrintf("PlaySoundFile/4: %s", tostring(sound))
						PlaySoundFile(sound, "master")
					end
				else
					modle:DebugPrintf("PlaySound/5: std sound")
					PlaySound(SOUNDKIT.AUCTION_WINDOW_OPEN, "master")
				end
			end
		end
	else
		modle:DebugPrintf("PlaySound/6: std sound")
		PlaySound(SOUNDKIT.AUCTION_WINDOW_OPEN, "master")
	end
end

function modle.GetOptions(uiType, uiName, appName)
	if appName == addonName then

		local options = {
			type = "group",
			name = addon.METADATA.NAME .. " (" .. addon.METADATA.VERSION .. ")",
			get = function(info)
					return addon.db.global[info[#info]] or ""
				end,
			set = function(info, value)
					addon.db.global[info[#info]] = value
					addon:Update()
				end,
			args = {
				desc1a = {
					type = "description",
					order = 0.1,
					name = "|cff99ccff-: by " .. GetAddOnMetadata(addonName, "Author") .. " :-|r|n|n" .. GetAddOnMetadata(addonName, "Notes"),
					fontSize = "medium",
				},
				desc1b = {
					type = "description",
					order = 0.2,
					name = "",
				},
				header01 = {
					type = "header",
					name = L["Alarm Window"],
					order = 0.3,
				},
				closeOnEscape = {
					type = "toggle",
					name = L["Close Window with Escape"],
					desc = L["If checked, the alarm window can be closed by pressing 'Esc'."],
					order = 0.5,
					width = "double",
					get = function(info) return addon.db.global[info[#info]] end,
				},
				windowFullMode = {
					type = "toggle",
					name = L["Show Bigger Window"],
					desc = L["If checked, the window is bigger and looting may be disabled."],
					order = 0.6,
					width = "normal",
					get = function(info) return addon.db.global[info[#info]] end,
				},
				windowTransparent = {
					type = "toggle",
					name = L["Transparent Window Background"],
					desc = L["If checked, the background of the alarm window is transparent."],
					order = 0.7,
					width = "double",
					get = function(info) return addon.db.global[info[#info]] end,
				},
			},
		}

		local cnt = 1
		for m in pairs(addon.modules) do
			if addon[m].ModuleName then
				cnt = cnt + 1
				local o = {
					type = "header",
					name = format(L["Detection Module: |cffffffff%s|r"], m),
					order = cnt,
				}
				options.args["header" .. m] = o

				if addon[m].TriggerDesc then
					cnt = cnt + 1
					o = {
						type = "description",
						name = addon[m].TriggerDesc and addon[m].TriggerDesc() or "",
						order = cnt,
					}
					options.args["desc" .. m] = o
				end

				cnt = cnt + 1
				o = {
					type = "toggle",
					name = format(L["Enable Module |cfffed100%s|r"], m),
					desc = format(L["If checked, alarms from module %s are displayed."], m),
					order = cnt,
					width = "double",
					get = function(info) return addon.db.global[info[#info]] end,
					set = function(info, value)
						addon.db.global[info[#info]] = value
						addon:Update()
					end,
				}
				options.args[m] = o

				if addon.db.global[m] then
					cnt = cnt + 1
					o = {
						type = "select",
						name = L["Alarm Sound:"],
						desc = L["Select the sound that is played if the module fires an alarm. Disable sound with 'None'."],
						order = cnt,
						width = "normal",
						dialogControl = "LSM30_Sound",
						values = WidgetLists.sound,
						get = function() return addon.db.global["Sound" .. m] end,
						set = function(_, value)
							-- value = "Default"
							addon.db.global["Sound" .. m] = value
							modle:DebugPrintf("LSM: Key=%s", value)
							if LSM and value and LSM:Fetch("sound", value) then
								local sound = LSM:Fetch("sound", value)
								if sound then
									if type(sound) == "string" then
										modle:DebugPrintf("LSM: String=%s", sound)
									end
									if type(sound) == "number" then
										modle:DebugPrintf("LSM: Number=%s", tostring(sound))
									end
								end
							end
						end,
					}
					options.args["soundoptions" .. m] = o

					if addon[m].GetOptions then
						cnt = cnt + 1
						o = addon[m].GetOptions()
						options.args["options" .. m] = o
						options.args["options" .. m].order = cnt
					end
				end
			end
		end

		return options
	end
end

-- EOF
