------------------------------------------------------------------------------
-- MakeMeGetMyMain - Alarms you when something happens to your character
------------------------------------------------------------------------------
-- Trigger_Move.lua - Triggered if character has been/was moved
--
-- Author: Expelliarm5s / October 2020 / All Rights Reserved
--
-- Version 1.1.7
------------------------------------------------------------------------------
-- luacheck: ignore 212 globals DLAPI C_Map

local addonName, addon = ...
local modle = addon:NewModule("Move", "AceEvent-3.0", "AceConsole-3.0")
local L = LibStub("AceLocale-3.0"):GetLocale(addonName)
local private = {}
------------------------------------------------------------------------------

private.x = 0
private.y = 0
private.after = 5  -- kicks in after 5 seconds

function modle:ModuleName()
	return modle.moduleName
end

function modle:ModuleIcon()
	if addon.isClassic then
		return "INTERFACE\\ICONS\\Ability_Creature_Cursed_03"
	else
		return "INTERFACE\\ICONS\\Spell_Shadow_FelMending"
	end
end

function modle:Position()
	local x,y
	local map = C_Map.GetBestMapForUnit("player")
	if map then
		local position = C_Map.GetPlayerMapPosition(map, "player")
		if position then
			x, y = position:GetXY()
			x = floor(x * 1000 + 0.5) / 10
			y = floor(y * 1000 + 0.5) / 10
			return x,y
		else
			return 0,0
		end
	end
end

function modle:Login()
	addon:DebugPrintf("%s:Login()", modle.moduleName)
	private.x, private.y = modle:Position()
	addon:DebugPrintf(modle.moduleName .. "~  x=%s, y=%s", tostring(private.x), tostring(private.y))
end

function modle:TriggerName()
	return L["Character got moved!"]
end

function modle:TriggerDesc()
	return L["Alarm fires on character move."]
end


function modle:SecTimer()
	-- addon:DebugPrintf("%s:SecTimer", modle.moduleName)
	local newx, newy = modle:Position()

	-- kick in after some seconds
	if private.after > 0 then
		addon:DebugPrintf(modle.moduleName .. "~  to soon!")
		private.after = private.after - 1
		private.x = newx
		private.y = newy
		return
	end

	if newx ~= private.x or newy ~= private.y then
		private.x = newx
		private.y = newy
		addon:DebugPrintf(modle.moduleName .. "~  x=%s, y=%s", tostring(private.x), tostring(private.y))
		if addon.isEnabled and addon.db.global[modle.moduleName] then
			addon:DebugPrintf(modle.moduleName .. "~  -> GUI:Fire(%s)", modle.moduleName)
			addon:Printf("Module " .. modle.moduleName .. ": " .. modle:TriggerName())
			if addon.GUI.Fire then
				addon.GUI:Fire(modle.moduleName)
			end
		end
	end
end

-- EOF